![image](https://user-images.githubusercontent.com/49507721/111910368-0cd8d400-8a9c-11eb-9167-57f101761286.png) 
![wlt32](https://user-images.githubusercontent.com/49507721/111910558-d3ed2f00-8a9c-11eb-9b8a-67f994e51358.png)
![wlt48](https://user-images.githubusercontent.com/49507721/111910537-bfa93200-8a9c-11eb-9912-630a55d48400.png)  

# USTCWlt

这是一个提供登录中国数学物理大学（USTC）网络通和设置网络功能的Python库

具体信息请访问[homepage](https://github.com/littzhch/USTCWlt)

